
******************************************************************
*
* PANEL-ANALYSIS (using an artificial dataset)
*
* JOSEF BRDERL, UNIVERSITY OF MANNHEIM, March 2015
*
******************************************************************

* This DO-File contains the STATA commands for the
* FEIS simulation

* These are the variables in the dataset:
* id      person identifier
* time    # panel wave
* marr    marriage dummy (1=married)
* marrdur duration of marriage
* wage    monthly wage in Euro (discrete treatment effect, non-parallel trends)
* wage1   monthly wage in Euro (accumulating treatment effect, parallel trends)
* wage2   monthly wage in Euro (accumulating treatment effect, non-parallel trends)


*************************************
** Preliminaries    *****************
*************************************
clear 
set more off

* Load data
cd  "K:\Vorlesung PDA\Stata Beispiele\Artificial Data\"    //Adapt this path!
use "FEIS Simulation.dta", clear

***** Declare data to be panel data *****
xtset id time

* Dummies needed for xtfeis
gen mdur1 = marrdur==1
gen mdur2 = marrdur==2
gen mdur3 = marrdur==3


******************************************
* Discrete Treatment Effect (non-parallel trends)
******************************************
twoway  (scatter wage time, ylabel(0(1000)5000, grid angle(0))           ///
                 ymtick(500(1000)4500, grid) c(L))                       ///
        (scatter wage time if marr==1, c(L)),                            ///
        legend(pos(7) ring(0) row(1) label(1 "before marriage") label(2 "after marriage"))


xtreg wage marr time, fe            //FE
est store FE

reg wage marr ibn.id ibn.id#c.time, noconstant  //POLSIS
est store POLSIS

xtfeis wage marr, slope(time)       //FEIS
est store FEIS

estimates table FE POLSIS FEIS, b(%7.0f) stats(N) ///
                keep(marr time i.id i.id#c.time)


******************************************
* Accumulating Treatment Effect (parallel trends)
******************************************
twoway  (scatter wage1 time, ylabel(0(1000)5000, grid angle(0))           ///
                 ymtick(500(1000)4500, grid) c(L))                       ///
        (scatter wage1 time if marr==1, c(L)),                            ///
        legend(pos(7) ring(0) row(1) label(1 "before marriage") label(2 "after marriage"))


xtreg wage1 i.marrdur time, fe                //FE
est store FE

reg wage1 i.marrdur ibn.id ibn.id#c.time, noconstant  //POLS with individual specific trends
est store POLSIS

xtfeis wage1 mdur?, slope(time)      //FEIS
est store FEIS

estimates table FE POLSIS FEIS, b(%7.0f) stats(N) ///
                keep(i.marrdur time mdur? i.id i.id#c.time)

				
******************************************
* Accumulating Treatment Effect (non-parallel trends)
******************************************
twoway  (scatter wage2 time, ylabel(0(1000)5000, grid angle(0))           ///
                 ymtick(500(1000)4500, grid) c(L))                       ///
        (scatter wage2 time if marr==1, c(L)),                            ///
        legend(pos(7) ring(0) row(1) label(1 "before marriage") label(2 "after marriage"))


xtreg wage2 i.marrdur time, fe                //FE
est store FE

reg wage2 i.marrdur ibn.id ibn.id#c.time, noconstant  //POLS with individual specific trends
est store POLSIS

xtfeis wage2 mdur?, slope(time)      //FEIS
est store FEIS

estimates table FE POLSIS FEIS, b(%7.0f) stats(N) ///
                keep(i.marrdur time mdur? i.id i.id#c.time)




